OC.L10N.register(
    "tasks",
    {
    "Tasks" : "任务",
    "Important" : "重要",
    "Today" : "今天",
    "Week" : "星期",
    "All" : "全部",
    "Current" : "当前",
    "Completed" : "完成",
    "The Tasks app for Nextcloud" : "Nextcloud 任务应用",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates, reminder times, mark them as important, and add comments on them. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client - Thunderbird, Evolution, KDE Kontact, iCal... - just add the calendar as a remote calendar in you client). You can download your tasks as ICS files using the download button for each calendar." : "在启用后，Nextcloud 应用菜单中将显示一个新的“任务”菜单。从那里，您可以添加和删除任务，编辑其标题，描述，开始和截止日期，提醒时间，将其标记为重要，并添加注释。任务可以在用户之间共享。可以使用 CalDav 同步任务（每个任务列表链接到 Nextcloud 日历，将其同步到本地客户端 - Thunderbird，Evolution，KDE Kontact，iCal ... - 只需将日历添加为客户端中的远程日历）。您可以使用每个日历的下载按钮将任务下载为 ICS 文件。",
    "Share with users or groups" : "和用户或者群组共享",
    "No users or groups" : "无用户或群组",
    "can edit" : "可编辑",
    "Unable to delete the share." : "无法删除此共享。",
    "Unable to change permissions." : "无法修改权限。",
    "Delete" : "删除",
    "Cancel" : "取消",
    "Delete all completed tasks." : "删除所有已完成任务。",
    "Delete completed tasks." : "删除已完成任务。",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "从日历 \"{calendar}\" 中删除所有已完成任务。",
    "No errors" : "没有错误",
    "Open your browser console for more details" : "打开您的浏览器控制台以获取更多详细信息",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["此操作将从日历 \"{calendar}\" 中删除 {taskCount} 个已完成任务及其子任务。"],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["无法删除 {failedCount} 个任务。"],
    "Load all completed tasks." : "载入所有已完成任务。",
    "Change sort order" : "更改排序",
    "Default" : "默认",
    "Sort by completed state, due date, priority, start date and summary." : "按已完成状态，截止日期，优先级，开始日期及概况排序",
    "Due date" : "截止日期",
    "Sort by due date and summary." : "按到期日及概况排序",
    "Start date" : "开始日期",
    "Sort by start date and summary." : "按开始日期及概况排序",
    "Created date" : "创建日期",
    "Sort by created date and summary." : "按创建日期及概况排序",
    "Last modified" : "上一次更改",
    "Sort by last-modified date and summary." : "按上次修改时期和摘要排序。",
    "Completed date" : "完成日期",
    "Sort by completed date." : "按完成日期排序。",
    "Priority" : "优先级",
    "Sort by priority and summary." : "按优先级和摘要排序。",
    "Manually" : "手动",
    "Sort by manual order." : "按手动顺序排序。",
    "Alphabetically" : "字母序",
    "Sort by summary and priority." : "按摘要和优先级排序。",
    "Task is completed" : "任务完成",
    "{complete} % completed" : "{complete} % 已完成",
    "Toggle visibility of completed subtasks." : "切换已完成子任务的可见性。",
    "Toggle visibility of all subtasks." : "切换所有子任务的可见性。",
    "[Yesterday]" : "[昨天]",
    "[Today]" : "[今天]",
    "[Tomorrow]" : "[明天]",
    "Add a subtask to \"{task}\"…" : "添加子任务到 \"{task}\" ...",
    "Add a task to \"{task}\"…" : "添加任务到 \"{task}\" ...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n 任务完成"],
    "Add an important task to \"{calendar}\"…" : "添加重要任务到 \"{calendar}\" ...",
    "Add a task due today to \"{calendar}\"…" : "添加今天截止的任务到 \"{calendar}\" ...",
    "Add a current task to \"{calendar}\"…" : "添加当前任务到 \"{calendar}\" ...",
    "Add a task to \"{calendar}\"…" : "添加任务到 \"{calendar}\" ...",
    "Tomorrow" : "明天",
    "Set start date" : "设置开始日期",
    "Set start time" : "设置开始时间",
    "Set due date" : "设置截止日期",
    "Set due time" : "设置截止时间",
    "All day" : "所有天",
    "Select a calendar" : "选择一个日历",
    "Select a classification" : "选择类别",
    "Select categories" : "选择分类",
    "Add this as a new category" : "添加此项作为新的分类",
    "Task not found!" : "没有任务！",
    "[Starts today]" : "[今天开始]",
    "[Starts tomorrow]" : "[明天开始]",
    "[Starts on] LL" : "[开始于] LL",
    "[Started yesterday]" : "[已开始于昨天]",
    "[Started on] LL" : "[已开始于] LL",
    "[Started today at] LT" : "[已开始于今天的] LT",
    "[Starts today at] LT" : "[开始于今天的] LT",
    "[Starts tomorrow at] LT" : "[开始于明天的] LT",
    "[Starts on] LL [at] LT" : "[开始于] LL [的] LT",
    "[Started yesterday at] LT" : "[已开始于昨天的] LT",
    "[Started on] LL [at] LT" : "[已开始于] LL [的] LT",
    "[Due today]" : "[今天截止]",
    "[Due tomorrow]" : "[明天截止]",
    "[Due on] LL" : "[截止于] LL",
    "[Was due yesterday]" : "[已于昨天截止]",
    "[Was due on] LL" : "[已截止于] LL",
    "[Was due today at] LT" : "[已截止于今天的] LT",
    "[Due today at] LT" : "[截止于今天的] LT",
    "[Due tomorrow at] LT" : "[截止于明天的] LT",
    "[Due on] LL [at] LT" : "[截止于] LL [的] LT",
    "[Was due yesterday at] LT" : "[已截止于昨天的] LT",
    "[Was due on] LL [at] LT" : "[已截止于] LL [的] LT",
    "No priority assigned" : "未设置优先级",
    "Priority {priority}: high" : "优先级 {priority}：高",
    "Priority {priority}: medium" : "优先级 {priority}：中",
    "Priority {priority}: low" : "优先级 {priority}：低",
    "{percent} % completed" : "{percent} % 已完成",
    "When shared show full event" : "共享时显示完整事件",
    "When shared show only busy" : "共享时仅显示进行中的事件",
    "When shared hide this event" : "共享时隐藏本事件",
    "Completed {date}" : "完成日期 {date}",
    "Created {date}" : "创建日期 {date}",
    "Last modified {date}" : "上一次更改 {date}",
    "Edit" : "编辑",
    "Copy private link" : "复制私人链接",
    "Copied" : "已复制",
    "Can not copy" : "无法复制",
    "Download" : "下载",
    "Save" : "保存",
    "Add List…" : "添加列表 ...",
    "New List" : "新列表",
    "Calendar link copied to clipboard." : "日历链接已复制到剪贴板。",
    "Calendar link could not be copied to clipboard." : "日历链接无法复制到剪贴板。",
    "The name \"{calendar}\" is already used." : "名称 \"{calendar}\" 已被使用。",
    "An empty name is not allowed." : "不允许使用空名称。",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "此操作将删除日历\"{calendar}\"以及所有相应的事件和任务。",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["与 {num} 个实体共享"],
    "Settings" : "设置",
    "Default list" : "默认列表",
    "Visibility of Smart Collections" : "智能集合的可见性",
    "Hidden" : "隐藏",
    "Visible" : "可见",
    "Automatic" : "自动",
    "Could not delete the task." : "无法删除任务。",
    "Synchronizing to the server." : "正在同步到服务器。",
    "Task successfully saved to server." : "任务已成功保存到服务器。",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "无法更新任务，因为它已在服务器上被更改。请点击以刷新此任务，本地变更将被丢弃。",
    "Could not update the task." : "无法更新任务。",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discared." : "无法更新任务，因为它已在服务器上被修改。请点击以刷新它，本地变更将被丢弃。",
    "An error occurred" : "发生了一个错误"
},
"nplurals=1; plural=0;");
